.. include:: ../../README.rst
    :end-line: 52

.. include:: _key_contributors.rst

.. toctree::
    :caption: Overview
    :maxdepth: 2
    :hidden:

    installation
    api
    example
    acknowledgments
    references

.. |br| raw:: html

  <br/>
